.. :changelog:

History
=======

0.3.1 (unreleased)
^^^^^^^^^^^^^^^^^^

* Fix history formatting preventing proper pypi release

0.3.0 (2020-07-05)
^^^^^^^^^^^^^^^^^^

* Add Django 2.2 / django CMS 3.7+ support
* Drop older Django / django CMS versions

0.2.0 (2018-09-25)
^^^^^^^^^^^^^^^^^^

* Add Django 1.11 / django CMS 3.4+ support
* Drop older Django / django CMS versions
* Improve documentation

0.1.0 (unreleased)
^^^^^^^^^^^^^^^^^^

* First experimental release
